Step

Struct Step 

pub struct Step<D, P, T, ID> { /* private fields */ }
Represent an active stage in the transformation pipeline.

Implementations

Source

impl<D, P, T, ID> Step<D, P, T, ID>

pub fn step<NewD, T1, T2>( self, decorator: NewD, ) -> Step<NewD, Self, T1, StepIndex<ID>>
where NewD: Decorator<T1, T2>, D: Decorator<T, T1>,

Applies a transformation to the current value and potentially changes existing type

However, the transformation is lazy which means it only takes effect after you consume Step value. Typical step registrations would be simply stacked up to produce a chain of step pipeline.

pub fn get_index(&self) -> usize
where ID: StepIndexBase,

Provide the depth for the current step. At any time you can query where the current step’s at.