Collector

Trait Collector 

pub trait Collector<T> {
    // Required method
    fn collect(self) -> Result<T>;
}
This trait imposes the standard behavior which Steps should follow.

Upon invoking, it would trigger the collection by processing any piled up Decorator.

Required Methods

fn collect(self) -> Result<T>

Implementors

Source

impl<D, P, T, ID, O> Collector<O> for GuardedStep<D, P, T, ID>
where D: Decorator<T, O>, P: Collector<T>,

Source

impl<D, P, T, ID, O> Collector<O> for Step<D, P, T, ID>
where D: Decorator<T, O>, P: Collector<T>,