pub struct Step<D, P, T, ID> { /* private fields */ }Expand description
Represent an active stage in the transformation pipeline.
Implementations
Sourceimpl<D, P, T, ID> Step<D, P, T, ID>
impl<D, P, T, ID> Step<D, P, T, ID>
Sourcepub fn step<NewD, T1, T2>(
self,
decorator: NewD,
) -> Step<NewD, Self, T1, StepIndex<ID>>
pub fn step<NewD, T1, T2>( self, decorator: NewD, ) -> Step<NewD, Self, T1, StepIndex<ID>>
Applies a transformation to the current value and potentially changes existing type
However, the transformation is lazy which means it only takes effect after you consume Step value.
Typical step registrations would be simply stacked up to produce a chain of step pipeline.