pub trait Collector<T> {
// Required method
fn collect(self) -> Result<T>;
}Expand description
This trait imposes the standard behavior which Steps should follow.
Upon invoking, it would trigger the collection by processing any piled up Decorator.